#[non_exhaustive]pub enum SnapshotValidationError {
AdapterIdentity(AdapterIdentityError),
Status(SnapshotStatus),
}Expand description
Why a snapshot could not be safely validated by the linked adapter.
The identity variant is returned before any validator call receives Rust-owned output pointers. A native status is returned only after the linked adapter has been authorized.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AdapterIdentity(AdapterIdentityError)
Status(SnapshotStatus)