pub fn runtime_identity() -> Option<AdapterIdentity>Expand description
Returns the runtime identity compiled into the linked adapter.
pub fn runtime_identity() -> Option<AdapterIdentity>Returns the runtime identity compiled into the linked adapter.