pub fn verify_runtime_identity() -> Result<AdapterIdentity, AdapterIdentityError>Expand description
Reads and authorizes the linked adapter before any non-adapter Box2D FFI call.
pub fn verify_runtime_identity() -> Result<AdapterIdentity, AdapterIdentityError>Reads and authorizes the linked adapter before any non-adapter Box2D FFI call.