pub unsafe extern "C" fn b2CollideCapsuleAndCircle(
capsuleA: *const b2Capsule,
circleB: *const b2Circle,
xf: b2Transform,
) -> b2LocalManifoldExpand description
Compute the contact manifold between a capsule and circle
pub unsafe extern "C" fn b2CollideCapsuleAndCircle(
capsuleA: *const b2Capsule,
circleB: *const b2Circle,
xf: b2Transform,
) -> b2LocalManifoldCompute the contact manifold between a capsule and circle