pub unsafe extern "C" fn b2CollideCapsules(
capsuleA: *const b2Capsule,
capsuleB: *const b2Capsule,
xf: b2Transform,
) -> b2LocalManifoldExpand description
Compute the contact manifold between a capsule and circle
pub unsafe extern "C" fn b2CollideCapsules(
capsuleA: *const b2Capsule,
capsuleB: *const b2Capsule,
xf: b2Transform,
) -> b2LocalManifoldCompute the contact manifold between a capsule and circle