pub unsafe extern "C" fn b2CollidePolygonAndCapsule(
polygonA: *const b2Polygon,
capsuleB: *const b2Capsule,
xf: b2Transform,
) -> b2LocalManifoldExpand description
Compute the contact manifold between a polygon and capsule
pub unsafe extern "C" fn b2CollidePolygonAndCapsule(
polygonA: *const b2Polygon,
capsuleB: *const b2Capsule,
xf: b2Transform,
) -> b2LocalManifoldCompute the contact manifold between a polygon and capsule