pub unsafe extern "C" fn b2CollidePolygonAndCircle(
polygonA: *const b2Polygon,
circleB: *const b2Circle,
xf: b2Transform,
) -> b2LocalManifoldExpand description
Compute the contact manifold between a polygon and a circle
pub unsafe extern "C" fn b2CollidePolygonAndCircle(
polygonA: *const b2Polygon,
circleB: *const b2Circle,
xf: b2Transform,
) -> b2LocalManifoldCompute the contact manifold between a polygon and a circle