pub unsafe extern "C" fn b2CollideSegmentAndCapsule(
segmentA: *const b2Segment,
capsuleB: *const b2Capsule,
xf: b2Transform,
) -> b2LocalManifoldExpand description
Compute the contact manifold between an segment and a capsule
pub unsafe extern "C" fn b2CollideSegmentAndCapsule(
segmentA: *const b2Segment,
capsuleB: *const b2Capsule,
xf: b2Transform,
) -> b2LocalManifoldCompute the contact manifold between an segment and a capsule