pub unsafe extern "C" fn b2CollideSegmentAndCircle(
segmentA: *const b2Segment,
circleB: *const b2Circle,
xf: b2Transform,
) -> b2LocalManifoldExpand description
Compute the contact manifold between an segment and a circle
pub unsafe extern "C" fn b2CollideSegmentAndCircle(
segmentA: *const b2Segment,
circleB: *const b2Circle,
xf: b2Transform,
) -> b2LocalManifoldCompute the contact manifold between an segment and a circle