pub unsafe extern "C" fn b2CollideSegmentAndPolygon(
segmentA: *const b2Segment,
polygonB: *const b2Polygon,
xf: b2Transform,
) -> b2LocalManifoldExpand description
Compute the contact manifold between an segment and a polygon
pub unsafe extern "C" fn b2CollideSegmentAndPolygon(
segmentA: *const b2Segment,
polygonB: *const b2Polygon,
xf: b2Transform,
) -> b2LocalManifoldCompute the contact manifold between an segment and a polygon