pub unsafe extern "C" fn b2ComputeSegmentAABB(
shape: *const b2Segment,
transform: b2WorldTransform,
) -> b2AABBExpand description
Compute the bounding box of a transformed line segment
pub unsafe extern "C" fn b2ComputeSegmentAABB(
shape: *const b2Segment,
transform: b2WorldTransform,
) -> b2AABBCompute the bounding box of a transformed line segment