pub unsafe extern "C" fn b2GetGraphColor(index: c_int) -> b2HexColorExpand description
Get the visualization color assigned to a constraint graph color slot. The last index (B2_GRAPH_COLOR_COUNT - 1) is the overflow color.
pub unsafe extern "C" fn b2GetGraphColor(index: c_int) -> b2HexColorGet the visualization color assigned to a constraint graph color slot. The last index (B2_GRAPH_COLOR_COUNT - 1) is the overflow color.