pub unsafe extern "C" fn b2RecPlayer_GetFrameQuery(
player: *const b2RecPlayer,
index: c_int,
) -> b2RecQueryInfoExpand description
Get a recorded query from the most recently replayed frame by index.
pub unsafe extern "C" fn b2RecPlayer_GetFrameQuery(
player: *const b2RecPlayer,
index: c_int,
) -> b2RecQueryInfoGet a recorded query from the most recently replayed frame by index.