pub unsafe extern "C" fn b2RecPlayer_GetFrameQueryCount(
player: *const b2RecPlayer,
) -> c_intExpand description
Get the number of spatial queries recorded for the most recently replayed frame.
pub unsafe extern "C" fn b2RecPlayer_GetFrameQueryCount(
player: *const b2RecPlayer,
) -> c_intGet the number of spatial queries recorded for the most recently replayed frame.