pub unsafe extern "C" fn b2RecPlayer_GetFrameQueryHit(
player: *const b2RecPlayer,
queryIndex: c_int,
hitIndex: c_int,
) -> b2RecQueryHitExpand description
Get one result of a recorded query from the most recently replayed frame.
pub unsafe extern "C" fn b2RecPlayer_GetFrameQueryHit(
player: *const b2RecPlayer,
queryIndex: c_int,
hitIndex: c_int,
) -> b2RecQueryHitGet one result of a recorded query from the most recently replayed frame.