pub unsafe extern "C" fn b2RecPlayer_GetKeyframeBytes(
player: *const b2RecPlayer,
) -> usizeExpand description
Get all memory currently held by keyframes, including ring metadata, in bytes.
pub unsafe extern "C" fn b2RecPlayer_GetKeyframeBytes(
player: *const b2RecPlayer,
) -> usizeGet all memory currently held by keyframes, including ring metadata, in bytes.