pub unsafe extern "C" fn b2RecPlayer_Restart(player: *mut b2RecPlayer)Expand description
Rewind the player to the first step, recreating the replay world from the file.
pub unsafe extern "C" fn b2RecPlayer_Restart(player: *mut b2RecPlayer)Rewind the player to the first step, recreating the replay world from the file.