pub unsafe extern "C" fn b2RecPlayer_StepFrame(
player: *mut b2RecPlayer,
) -> boolExpand description
Advance the replay by one recorded step. @return true if a step executed, false once the end of the recording is reached
pub unsafe extern "C" fn b2RecPlayer_StepFrame(
player: *mut b2RecPlayer,
) -> boolAdvance the replay by one recorded step. @return true if a step executed, false once the end of the recording is reached