b2ShapeCast

Function b2ShapeCast 

pub unsafe extern "C" fn b2ShapeCast(
    input: *const b2ShapeCastPairInput,
) -> b2CastOutput
Perform a linear shape cast of shape B moving and shape A fixed. Determines the hit point, normal, and translation fraction. The query runs in frame A, so the hit point and normal are returned in frame A. Initially touching shapes are a miss.