#[repr(C)]pub struct b2LocalManifold {
pub normal: b2Vec2,
pub points: [b2LocalManifoldPoint; 2],
pub pointCount: c_int,
}Expand description
Contact manifold in local coordinates (frame A).
Fields
normal: b2Vec2The unit normal vector in frame A, points from shape A to shape B
points: [b2LocalManifoldPoint; 2]The manifold points, up to two are possible in 2D
pointCount: c_intThe number of contacts points, will be 0, 1, or 2