#[repr(C)]pub struct b2ShapeCastPairInput {
pub proxyA: b2ShapeProxy,
pub proxyB: b2ShapeProxy,
pub transform: b2Transform,
pub translationB: b2Vec2,
pub maxFraction: f32,
pub canEncroach: bool,
}Expand description
Input parameters for b2ShapeCast
Fields
proxyA: b2ShapeProxy< The proxy for shape A
proxyB: b2ShapeProxy< The proxy for shape B
transform: b2Transform< Transform of shape B in shape A’s frame, the relative pose B in A
translationB: b2Vec2< The translation of shape B, in A’s frame
maxFraction: f32< The fraction of the translation to consider, typically 1
canEncroach: bool< Allows shapes with a radius to move slightly closer if already touching