b2TaskCallback

Type Alias b2TaskCallback 

pub type b2TaskCallback = Option<unsafe extern "C" fn(taskContext: *mut c_void)>;
Task interface This is the prototype for a Box2D task. Your task system is expected to run this callback on a worker thread, exactly once per enqueue, passing back the same taskContext pointer supplied to b2EnqueueTaskCallback. @ingroup world

Aliased Type

pub enum b2TaskCallback {
    None,
    Some(unsafe extern "C" fn(*mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void))

Some value of type T.