b2WorldCastOutput

Type Alias b2WorldCastOutput 

pub type b2WorldCastOutput = b2CastOutput;
Low level ray cast or shape-cast output data. The hit point is in the local or relative frame of the input. Returns a zero fraction and normal in the case of initial overlap.

Aliased Type

#[repr(C)]
pub struct b2WorldCastOutput { pub normal: b2Vec2, pub point: b2Vec2, pub fraction: f32, pub iterations: i32, pub hit: bool, }

Fields

normal: b2Vec2

The surface normal at the hit point

point: b2Vec2

The surface hit point

fraction: f32

The fraction of the input translation at collision

iterations: i32

The number of iterations used

hit: bool

Did the cast hit?