pub unsafe extern "C" fn b2DynamicTree_BoxCast(
tree: *const b2DynamicTree,
input: *const b2BoxCastInput,
maskBits: u64,
callback: b2TreeBoxCastCallbackFcn,
context: *mut c_void,
) -> b2TreeStatsExpand description
Cast a swept AABB through the tree. This has performance roughly equal to k * log(n),
where k is the number of collisions and n is the number of proxies in the tree.
@param tree the dynamic tree to cast through
@param input the AABB cast input. The box sweeps from its origin to origin + maxFraction * translation.
@param maskBits filter bits: bool accept = (maskBits & node->categoryBits) != 0;
@param callback a callback that is called for each proxy the swept box may hit
@param context user context that is passed to the callback
@return performance data