pub unsafe extern "C" fn b2Shape_SetChainSegment(
shapeId: b2ShapeId,
chainSegment: *const b2ChainSegment,
)Expand description
Allows you to change a shape to be an orphaned chain segment or update the current chain segment, including its ghost vertices. The chainId on the input is ignored. The resulting shape is always orphaned. Asserts if the shape is already a chain segment owned by a b2ChainShape (chainId != B2_NULL_INDEX).