pub unsafe extern "C" fn b2World_CollideMover(
worldId: b2WorldId,
origin: b2Pos,
mover: *const b2Capsule,
filter: b2QueryFilter,
fcn: b2PlaneResultFcn,
context: *mut c_void,
)Expand description
Collide a capsule mover with the world, gathering collision planes that can be fed to b2SolvePlanes. Useful for kinematic character movement. The mover capsule and the resulting planes are relative to the origin.