pub unsafe extern "C" fn b2World_OverlapAABB(
worldId: b2WorldId,
origin: b2Pos,
aabb: b2AABB,
filter: b2QueryFilter,
fcn: b2OverlapResultFcn,
context: *mut c_void,
) -> b2TreeStatsExpand description
Overlap test for all shapes that potentially overlap the provided AABB. The AABB is relative to the origin, which keeps the test precise far from the world origin in large world mode. Near the origin pass b2Pos_zero and a world AABB.