#[repr(C)]pub struct b2ContactHitEvent {
pub shapeIdA: b2ShapeId,
pub shapeIdB: b2ShapeId,
pub contactId: b2ContactId,
pub point: b2Pos,
pub normal: b2Vec2,
pub approachSpeed: f32,
}Expand description
A hit touch event is generated when two shapes collide with a speed faster than the hit speed threshold. This may be reported for speculative contacts that have a confirmed impulse.
Fields
shapeIdA: b2ShapeIdId of the first shape
shapeIdB: b2ShapeIdId of the second shape
contactId: b2ContactIdId of the contact. @warning this contact may have been destroyed @see b2Contact_IsValid
point: b2PosPoint where the shapes hit. This is a mid-point between the two surfaces. It could be a speculative point where the shapes were not touching at the beginning of the time step. The point is reconstructed after the step, so when both bodies are moving it may trail the impact by up to one step of motion.
normal: b2Vec2Normal vector pointing from shape A to shape B
approachSpeed: f32The speed the shapes are approaching. Always positive. Typically in meters per second.