pub type b2EnqueueTaskCallback = Option<unsafe extern "C" fn(task: b2TaskCallback, taskContext: *mut c_void, userContext: *mut c_void) -> *mut c_void>;Expand description
These functions can be provided to Box2D to invoke a task system. Returns a pointer to the user’s task object. May be nullptr. A nullptr indicates to Box2D that the work was executed serially within the callback and there is no need to call b2FinishTaskCallback. @ingroup world
Aliased Type
pub enum b2EnqueueTaskCallback {
None,
Some(unsafe extern "C" fn(Option<unsafe extern "C" fn(*mut c_void)>, *mut c_void, *mut c_void) -> *mut c_void),
}